#include <stdio.h>
/*
	splicer_defs.h
*/

#define	MAXBUF		(500)
#define	ALLOC_INT	(100)
#define CHAR_SIZE	sizeof(char)

/*max array size for 'dummy' cleaned up core data
  used for plotting and correlation and array
  sizes for structs defined in this file.
*/
#define MAXHOLE         10            /* maximun number of holes */
#define MAXCORE        200            /* maximun number of cores per hole */
#define MAXSPCORE      500            /* maximum number of cores in a splice record */
#define MAXPERCORE    2000            /* maximum number of points per core */
#define MAXCORR       1000            /* maximum number of correlations; lead + lag + 1*/
#define MAXAGE        1000
#define NDATASET         9

#define SHIP      1
#define SHORE     2
int whereami;

typedef	struct	_MessageInfo
{
	char	*label;
	int	fatal,
		error,
		caller;
	unsigned char	type,
			default_button;
} MessageInfo;

/* caller functions */
#define	OPENOK			(0)
#define	BADMEMALLOC		(1)
#define	OUTPUTDATA		(2)
#define	SPREADMST95REPORT	(3)
#define	SPINPUTDATA		(4)
#define	SPREADAFFINETABLE	(5)
#define	SPWRITEAFFINETABLE	(6)
#define	SPVIEWLOG		(7)
#define	SPREADTKREPORT		(8)
#define	SPREADCULLTABLE		(9)
#define	SPCULLTABLE		(10)
#define	SPMANAGEWARNINGBOX	(11)
#define	SPREADOTHERODP		(12)
#define	SPFILESELECTIONBOXCB	(13)
#define	SPSMOOTH		(14)
#define SPREADJANUS             (15)

typedef	struct	_HashInfo
{
	int	leg;
	char	subleg;
	int	site;
	int	value2;
	char	hole;
	int	core;
	char	coretype;
	char	section[3];
	float	top_int;
	int	value;
} HashInfo;

typedef	struct	_SplicerTableInfo
{
        int     site;
	char    hole;
	int     core;
	char    core_type;
	char	section[3]; 
        char    type_of_splice[10];
	float   top_int,
		bot_int,
		mbsf,  
		mcd;
} SplicerTableInfo;


typedef	struct	_SplicerTableFile
{
	char	*filename;
	char	*dirname;
	int	alloc_cnt,
		data_cnt;
	SplicerTableInfo	*data;
} SplicerTableFile;

typedef	struct	_ODPKey
{
	int	leg,
                subleg,
                site,
                core,
                in_affine,
                aff_map_hole,
                aff_map_core;
	char	section[3],
		hole,
                coretype;
	float	interval,
		sb_depth,
		offset;
} ODPKey;

typedef	struct	_StratData
{
	char	name[100],
		code[20];
        int     type,
                x_pix_loc_edit,
                y_pix_loc_edit,
                x_pix_loc_view,
                y_pix_loc_view,
                x_pix_loc_agedepth,
                y_pix_loc_agedepth,
                x_pix_loc_splicetoage,
                y_pix_loc_splicetoage,
                hole_is_in_dataset,
                agemodel_maptostratfile,
                agemodel_maptodatum;       
	float	top_age,
		bot_age,
                aveage,
                tunedage,
                avembsf,
                avemcd,
                sedrate;
	ODPKey	top,
		bot;
} StratData;

typedef	struct	_StratFile
{
	char	*filename,
		*dirname;
	int	type,
		alloc_cnt,
		data_cnt;
	StratData	*data;
} StratFile;

typedef	struct	_ReportFile
{
	char	*name;
	int	saveflag,	
		/* true if report file is to be saved */
		savecurrent;	
	/* true if report save from current position 
										 rather than start of report */
	FILE	*ptr;
	int	lineno;
} ReportFile;

typedef	struct	_AffineFile
{
	char	*filename,
		*dirname;
	int	usetable;
} AffineFile;

typedef struct  _AffineCore
{
  int    numhole;
  int    leg;
  int    site;
  int    name;
  char   type[2];
  float  mbsf;
  int    did_offset;
  int    data_map_to_core[NDATASET];
  float  cum_depth_offset;
} AffineCore;

typedef struct  _AffineHole
{
  int         numcore;
  char        name[2];
  int         data_map_to_hole[NDATASET];
  AffineCore  core[MAXCORE];
} AffineHole;

typedef struct  _AffineTable
{
  int         numhole;
  AffineHole  hole[MAXHOLE];
} AffineTable;

typedef struct _CompositeTable
{
  char map[100][50];
  float accum_depth_offset[100];
} CompositeTable;

typedef struct _Smooth
{
	int	method,
		plot,
		width,
		width_units;
	float	*weight;
} Smooth;

typedef	struct	_Equation
{
	float	value1,
		value2;
	int	sign1,
		sign2,
		join;
} Equation;

typedef	struct	_Cull
{
	int	method;
	char	*filename,
		*dirname;
	float	top,
		pwave_signal_max;
	int	by_core_num,
		max_core;
	Equation	grape,
			pwave,
			susceptibility,
			naturalgamma,
			reflectance,
			otherodp;
} Cull;

typedef	struct	_Grapedata
{
	float	density,
		b_corr_density;
	int	gamma_counts;
} Grapedata;

typedef	struct	_Pwavedata
{
	float	velocity;
	int	sig_strength,
		travel_time,
		displacement;
} Pwavedata;

typedef	struct	_Natgammadata
{
	int	sample_time;
        float   total_cnt,
		seg1_cnt,
		seg2_cnt,
		seg3_cnt,
		seg4_cnt,
		seg5_cnt;
} Natgammadata;

typedef struct	_Susceptibility
{
	float	observed,
		corrected;
} Susceptibility;

typedef	struct	_ReflectanceMST
{
	float	L,
		a,
		b;
	char	munsell_hue[7],
		munsell_value[10];
	float	nm_value[31];
} ReflectanceMST;

typedef struct  _ReflectanceOSU
{
  int    qual_mark,
         landing[9];
  float  mid_sect_dep,
         uv,
         blue,
         red,
         nir;
} ReflectanceOSU;

typedef	struct	_Value
{
	char	type;
	char	section[3];
	float	top_int,
		bot_int,
		sb_depth,
		sm_data,
		*data;
	Grapedata	*grape;
	Pwavedata	*pwave;
	Natgammadata	*naturalgamma;
	Susceptibility	*susceptibility;
	ReflectanceMST	*reflectanceMST;
        ReflectanceOSU  *reflectanceOSU;
	float	otherodp;
	int	run_num,
		quality,
                smooth_ok;
} Value;

typedef	struct	_Core
{
	int	num,
		numvalues,
		allocvalues,
                affine_map_to_core,
                core_map_to_affine,
                did_offset,
                smooth_status;
        float   cum_dep_offset;
	Value	**value;
} Core;

typedef struct	_Hole
{
	char	name;
        int     affine_map_to_hole,
                hole_map_to_affine;
	int	numcores;
	Core	**core;
} Hole;

typedef struct _DataFile
{
	char	**name;
	int	type,
		in_format,
		out_format,
		numfiles,
		readerrors,
		leg;
	char	subleg;
	int	site;
	int	numholes;
        int     decimate_value;
	char	*holes_used;
        float   min,
                max;
	Hole	**holes;
} DataFile;

typedef struct _TimeSeries
{
        char    *filename;
        char    *dirname;
        int    n;
        float  *age;
        float  *val;
        float  valperpix;
        float  minval;
        float  maxval;
        float  MaConvert;
} TimeSeries;


/* Program name tag */
#define	SPLICER_VERSION	"Splicer V. Motif/Demo"

/* Data types */
#define NUM_DATA_TYPES	(6)
#define	GRAPE		(0)
#define	PWAVE		(1)
#define	SUSCEPTIBILITY	(2)
#define	NATURALGAMMA	(3)
#define	REFLECTANCEMST	(4)
#define REFLECTANCEOSU  (5)
#define OTHERTYPE       (6)

/* default mins and maxs */
#define GRAPEMIN        (1.0)
#define GRAPEMAX        (3.0)
#define PWAVEMIN        (1500.0)
#define PWAVEMAX        (5000.0)
#define SUSCMIN         (-10.0)
#define SUSCMAX         (1000.0)
#define NGAMMAMIN       (0.0)
#define NGAMMAMAX       (1000.0)
#define REFLECTMIN      (0.0)
#define REFLECTMAX      (100.0)
#define OTHERMIN        (0.0)
#define OTHERMAX        (100.0)

static	char	*type[]={"GRAPE","PWAVE","SUSCEPTIBILITY","NATURAL GAMMA","REFLECTANCE", "OTHER"};

static	char	*output_type[]={"grfix","pwfix","susfix","ngfix","refl","other"};

/* Data Formats */
#define NUM_FORMATS	(7)
#define	MST95REPORT	(0)
#define	TKREPORT	(1)
#define OSUSCAT         (2)
#define JANUS           (3)
#define JANUSCLEAN      (4)
#define JANUSORIG       (5)
#define ODPOTHER        (6)
#define	ODPOTHER1	(7)
#define ODPOTHER2       (8)
#define ODPOTHER3       (9)
#define ODPOTHER4       (10)
#define ODPOTHER5       (11)

typedef struct _OpenFileInfo
{
    char  **in_file_names;
    int   in_data_type;
    int   in_data_format;
    int   num_in_files;
    int   other_format_value_col;
    char  other_format[100];
} OpenFileInfo;

static  char    *format[]={"MST95 REPORT","TK REPORT","OSU/SCAT","JANUS","JANUSCLEAN","JANUSORIG","ODP OTHER","ODP OTHER1","ODP OTHER2","ODP OTHER3","ODP OTHER4","ODP OTHER5"};

/* open */
#define	FILE_FILTER	(0)
#define	DIRECTORIES	(1)

/* smoothing*/
#define	NONE		(0)
#define	GAUSSIAN	(1)
#define	OTHER		(2)


#define	UNSMOOTHED	(0)
#define	SMOOTHED	(1)
#define	SMOOTHEDBOTH	(2)
#define SMOK            (1)
#define SMTAIL          (2)
#define SMBADDATA       (-1)
#define SMTOOFEWPTS     (-2)
#define SMBADCALC       (-3)
#define TOOFEWSMOOTHED  (5)    /* don't use smooth if have less than this number in a core */

#define MINSMOOTHWIDTH         (3)   /* 3 points or 3 * ave. depth step cms */
#define MAXSMOOTHWIDTHDEPTH  (400)   /* cms */
#define MAXSMOOTHWIDTHPOINTS (100)   /* points */

static	char	*plot_display[]={"Unsmoothed Only","Smoothed Only",
		"Both Smoothed and Unsmoothed"};

#define	DEPTH	(0)
#define	POINTS	(1)

static	char	*smooth_units[]={"Depth (cm)","Points"};

/* culling */
#define	LESS_THAN			(0)
#define	LESS_THAN_OR_EQUAL_TO		(1)
#define	GREATER_THAN			(2)
#define	GREATER_THAN_OR_EQUAL_TO	(3)
#define	EQUAL_TO			(4)

#define	OR	(1)
#define	ONLY	(2)

#define	CULL_PARAMETERS	         (1)
#define	CULL_TABLE	         (2)
#define CULL_PARAMETER_AND_TABLE (3)

#define CULLTABLEDEPTHCHECK      (1.0)   /* section cm depth to use for whether to cull a value using cull table*/
                                         /* is the sample this close to cull table */
#define TOOMANYCULLED            (95)    /* stop read if cull more than this percent */
#define WARNCULL                 (50)    /* cull warn if more than this percent were culled */ 

/* data quality flags */
#define	GOOD			(0)
#define	BAD_TOP			(1)
#define	BAD_CULL1		(2)
#define	BAD_CULL2		(4)
#define	DECIMATED		(8)
#define BAD_PWAVE_SIGNAL	(16)
#define	BAD_SB_DEPTH		(32)
#define	BAD_CORE_NUM		(64)
#define	BAD_CULLTABLE		(128)
#define BAD_REFLECTANCE         (256)

#define BAD_CODE        -999.99

#define TOOMANYOUTOFORDER   (100)

#define MEAN_DETREND     (1)
#define LINEAR_DETREND   (2)

/* hash values */
#define	CREATE_HASH	(1)
#define	DESTROY_HASH	(2)

/* strat types */
static	char	*strat_type[]={"Diatoms","Radiolaria","Foraminifera","Nannofossils","Paleomag"};
#define	DIATOMS		(0)
#define	RADIOLARIA	(1)
#define	FORAMINIFERA	(2)
#define	NANNOFOSSILS	(3)
#define	PALEOMAG	(4)
#define HANDPICK        (5)
#define TIME            (6)

/* clean up types */
#define NUM_CLEANUP_TYPES	(5)
static	char	*cleanup_type[]={"All","Data","Strat","Splicer","TimeSeries","Exit"};
#define	ALL			(0)
#define	INPUTDATA		(1)
#define	INPUTSTRAT		(2)
#define	INPUTSPLICERTABLE	(3)
#define TIMESERIES              (4)
#define	EXIT			(5)
#define CANCEL                 (99)

/* input/output types
*/
int         fileselection;
#define     SAVE             (1)
#define     OPEN             (2)
#define     PREVIEWINPUT     (1)
#define     OPENDATA         (2)
#define     OPENSTRAT        (3)
#define     OPENSPLICETABLE  (4)
#define     OPENAFFINE       (5)
#define     OPENCULLTABLE    (6)
#define     OPENAGEMODEL     (7)
#define     OPENTIMESERIES   (8)
#define     SAVECULLTABLE    (9)
#define     SAVEAFFINE      (10)
#define     SAVESPLICETABLE (11)
#define     SAVESTRAT       (12)
#define     SAVEDATA        (13)
#define     SAVESPLICEDATA  (14)
#define     SAVEAGEMODEL    (15)
#define     SAVESPLICEVSAGE (16)


/* the drawing area's graphic contexts
*/
GC        gc_drawingAreaEdit;
GC        gc_drawingAreaView;
GC        gc_drawingAreaTieCorrelation;
GC        gc_drawingAreaSpliceCorrelation;
GC        gc_drawingAreaDepthOffset;
GC        gc_drawingAreaAgeDepth;
GC        gc_drawingAreaAgeModel;
GC        gc_drawingAreaSpliceToAge;
GC        gc_drawingAreaTieToTimeSeriesCorr;

/* the cursor used in age-depth drawing area for dragging plot
*/
Cursor drag_cursor;
int    are_dragging;
int    last_x_agedepth;
int    last_y_agedepth;

#define  DEFINEWAITCURSOR       0
#define  FREEWAITCURSOR         1

/* drawing constraints 
*/
#define OFF                     50    /*pixels;  offset of axis from top left corner*/
#define YAXIS_ANNOT_OFF         25    /*pixels; offset of depth axis numbers*/
#define SPACE                   20    /*pixels; space between holes*/
#define VAR_AXIS_LEN           120    /*pixels; initial width of variable axis*/
#define SCALE_VALUE              0    /*meters; initial top value of scale widget*/
#define SCALE_MULT               2    /*meters; initial value scale widget will 'jump'*/
#define MINDEP                 0.0    /*meter; minimum depth*/
#define MAXDEP               100.0    /*meter; initial maximum depth*/
#define DEPTIC                 2.0    /*meters; depth tick*/
#define DEPMETERDISPLAYED     20.0    /*meter initial number of meters displayed*/
#define DEPPERPIX             0.01    /*meters; initial scale, meters per pixel*/
#define GAP                   1.00    /*meter; not used yet*/
#define CHECKSPLICEOFFSET     0.05    /*meter; splicing unconstrained check; warning if tie changes depth more than*/
#define CLOSE                    5    /*pixel check for cursor position close enough to real data*/
#define TOOFEWCORRPAIRS          5    /*discard correlatiions with fewer than this n*/
#define CHECKVALUEDIFF         0.1    /*check for value difference of good tie; fraction of std*/
#define ROUNDCHECK         0.00001    /*for equating two values same or not.*/
#define NCORESSTD                5    /*number of cores(from top, every hole) to find std in; to set var axis min & max*/
#define PLUSMINUSSTD           3.0    /*number of std awy from mean to set variable axis min & max*/
#define DEPTHCHANGE           10.0    /*initial percent depth change of composited cores for depth offset plot*/
#define AVEDEPTHSTEP             5    /*default average depth step (cm) for any one core*/
#define POINTSIZE                5    /*tie point size in pixels */
#define AGEDISPLAYED           1.0    /* display 1 million years */
#define AGETIC                 0.2
#define AGESCALEBARINC        0.05    /* percent of age displayed represented by one increment of age scale bar */
#define MINAGESINGLEDATUM     0.02    /* min age allowed(for calc-plot) if only have one datum in age model */
#define TOOMANYREADERRORS       50    /* limit of how many readerrors. if exceed; stop read */
#define ALLOWAPPENDOVERLAP    0.05    /* allow a core to be appended if overlap <= 5cm */

/* on,off's for whether have stuff or have done something
*/
#define DO            1
#define DONT          0
#define YES           1
#define NO            0
#define TIE1          1    /* TIE1 and TIE2 used to assign which core was the last to be picked */
#define TIE2          2    /* this is to know what core to act on if button move or arrows used */
#define CONSTRAINED   1    /* splicing constrained */
#define UNCONSTRAINED 2    /* splicing unconstrained */
#define REAL          1    /* when splicing constrained, is corresponding point on core to splice a real point*/
#define INTERPOLATED  2    /* or was it interpolated */
#define APPEND        3    /* or was the core appended */
#define ONECORE       1    /* when compositing, was last core shifted the only one shifted*/
#define ALLCORES      2    /* or were all cores below it also shifted */
#define ERR          -1
#define OVERLAPAPPEND 2    /* core to splice slightly overlaps; allow append */

#define MBSF          1
#define MCD           2

#define SPL_MISSING_HOLE   -1 /**/
#define SPL_MISSING_CORE   -2 /**/
#define SPL_NO_CORE_VALUES -3 /**/

#define SPL_UNDO_MISSING_CORE  -1
#define SPL_UNDO_TAILING_CORE  -2

/* reasons for redrawing
*/
#define DRAW_EVERYTHING       1    /* whatever happened; everyting in the window must be drawn */
#define DRAW_CLEAR            2    /* whatever happened; the window is being cleared */

#define DRAW_TIES             3    /* something has happened concerning tie(s); just draw area effected */
#define DRAW_DEPTHSHIFT       4    /* a core or cores have been depth shifted */
#define DRAW_DEPTHSHIFTUNDO   5    /* a core has been undepth shifted */
#define DISPLAY_CHANGE        6    /* something(s) in the display has been changed */

#define DRAW_COREGRABBED      7    /* a core to splice has been selected */
#define DRAW_CORECLEARED      8    /* a core to splice has been cleared */
#define DRAW_SPLICED          9    /* a core to splice has been spliced */
#define DRAW_APPEND          10    /* a core to splice has been appended */
#define DRAW_UNDONE          11    /* a splice has been undone */

#define DRAW_CLEARTIE        12    /* a tie has been cleared */

#define EDIT                  1
#define VIEW                  2
#define CLIP                  0    /* if no defaults file found; let clip be set to no */

int clip;
short int clip_x, clip_y;
unsigned short int clip_width, clip_height;
 
int    dataset_cnt;
int    dset;
int    have_data;
int    have_affine;
int    have_tie;
int    have_tie1;
int    have_tie2;
int    have_shift;
int    have_corr;
int    have_splice;
int    have_sp_tie1;
int    have_sp_tie2;
int    have_spcorr;
int    have_core_to_splice;
int    have_splice_tie;
int    have_splice_shift;
int    have_strat;
int    have_splicetoage;
int    have_time_series;
int    have_splicetoage_tie;
int    have_splicetoage_corr;
int    have_timeseries_tie;
int    draw_offsets;          /* draw in depth offset drawing area; Y-N. is it popped up */
int    are_compositing;
int    did_affine;
int    saved_affine;
int    are_splicing;
int    did_splicing;
int    write_report;
int    open_dataform_is_up;
int    saved_splice;
int    splice_overlap;        /* does the selected core to splice overlap the splice record; Y-N */
int    average_depth_step;    /* average depth step(cm) of entire site; used to check smooth filter width if by depth */
int    agemodel_cnt;
int    are_agemodelling; 
int    did_agemodel;
int    saved_agemodel;
int    agemodelling_depth_type;
int    agedepth_use_type[MAXAGE];
int    clear_what;

/*default lead,lag, depth step and window length
*/
#define LEADLAG    1.0     /* meters*/
#define LEADLAGMYR 0.025   /* Myrs */
#define WINLEN     2.0     /* meters*/
#define WINLENMYR  0.05    /* Myrs*/
#define DEPSTEP    0.1     /* meters*/
 
/* things will need in many functions regarding splice
   'ties' and correlation info
*/
int    tie1holenum;
int    tie1corenum;
int    tie1arraynum;
int    tie2holenum;
int    tie2corenum;
int    tie2arraynum;
int    tie_corr_num;
int    best_corr_num;
int    lastshiftwho;
int    lastdidoffsetstate;
int    spliceholenum;
int    splicecorenum;
int    splicearraynum;
int    spcompcorenum;
int    spcomparraynum;
int    splicetoagecorenum;
int    splicetoagearraynum;
int    timeseriesarraynum;
int    lead_lag;
int    last_tie;
int    last_sp_tie;
int    last_splicetoage_tie;
int    splice_how;
int    reason_for_redraw;
int    lastaffinehole;
int    lastaffinecore;
 
float  tiedepoffset;
float  splicedepoffset;
float  best_corr;
float  lastdepoffset;
float  interpsplice_val;
float  interpsplice_sm_val;
float  interpsplice_sb_depth;
float  interpsplice_spl_depth;
float  agemodel_handpick_depth;
float  agemodel_handpick_age;
float  agemodel_avesedrate;

double  leadlagmeters;
double  winlen;
double  depstep;
 
/*frequently used drawing variables like scales and such
*/
int    top_off_edit;
int    top_off_view;
int    top_off_agedepth_depth;
int    top_off_agedepth_age;
int    top_off_splicetoage;
int    scale_val;
int    scale_mult;
int    last_scale_val_edit;
int    last_scale_val_view;
int    lastagescaleval;
int    varaxislen;

float  maxdep;
float  top_meter_edit;
float  top_meter_view;
float  top_meter_agedepth;
float  top_age_agedepth;
float  top_age_splicetoage;
float  varperpix;
float  depperpix;
float  depperpixsp;
float  lagperpix;
float  corrperpix;
float  ageperpix;
float  depperpixagemodel;
float  offsetdepperpix;
float  depthoffsetperpix;
float  spliceageperpix;
float  sedrateperpix;
float  agedisplayed;

double minvar;
double maxvar;
double realminvar;
double realmaxvar;
double deptic;
double depmeterdisplayed;

float maxagedepdepth;
float maxagedepage;

/* data struct for the correlation values
*/
typedef struct _CorrelationTable
{
  int    lag,
         lead,
         num_lead_lag[NDATASET], 
         n[MAXCORR], 
         leadlag[NDATASET][MAXCORR];
  float  coef[NDATASET][MAXCORR],
         depoffset[MAXCORR],
         depleadlag[NDATASET][MAXCORR];
} CorrelationTable;

/* data struct for the splice 'composite'
*/
typedef struct _SpliceComp
{
  char   interpolated_section[MAXSPCORE][3];
  int    numcores,
         numpercore[MAXSPCORE],
         hole[MAXSPCORE],
         core[MAXSPCORE],
         splice_how[MAXSPCORE],
         MapToOrig[MAXSPCORE][MAXPERCORE],
         map_to_table[MAXSPCORE];

  float  Depthoffset[MAXSPCORE],
         sb_depth[MAXSPCORE][MAXPERCORE],
         interpolated_top_int[MAXSPCORE],
         interpolated_bot_int[MAXSPCORE],
         interpolated_sb_depth[MAXSPCORE],
         interpolated_spl_depth[MAXSPCORE],
         interpolated_value[MAXSPCORE],
         interpolated_sm_value[MAXSPCORE],
         var[MAXSPCORE][MAXPERCORE],
         age[MAXSPCORE][MAXPERCORE],
         sedrate[MAXSPCORE][MAXPERCORE];

} SpliceComp;

/* handles to the different types of lines and symbols
   that can be displayed in selected colors
*/
#define NCOLOR                36
#define BG_COLOR               0
#define LABEL_COLOR            1
#define MBSF_COLOR             2
#define MCD_COLOR              3
#define SMOOTH_COLOR           4
#define SPLICE_COLOR           5
#define SPLICELOCATION_COLOR   6
#define TIEPTFIXED_COLOR       7
#define TIEPTSHIFT_COLOR       8
#define TIELINE_COLOR          9
#define OVERLAYINCORR_COLOR   10
#define OVERLAYOUTCORR_COLOR  11
#define PALEOMAG_COLOR        12
#define DIATOM_COLOR          13
#define RAD_COLOR             14
#define FORAM_COLOR           15
#define NANNO_COLOR           16
#define CORRCOEF_COLOR        17
#define BESTCORR_COLOR        18
#define DEPOFFLINE_COLOR      19
#define DEPOFFHOLE1_COLOR     20
#define DEPOFFHOLE2_COLOR     21
#define DEPOFFHOLE3_COLOR     22
#define DEPOFFHOLE4_COLOR     23
#define DEPOFFHOLE5_COLOR     24
#define DEPOFFHOLE6_COLOR     25
#define DEPOFFHOLE7_COLOR     26
#define DEPOFFHOLE8_COLOR     27
#define DEPOFFHOLE9_COLOR     28
#define DEPOFFHOLE10_COLOR    29
#define DEPOFFHOLE11_COLOR    30 
#define AGEDEPHANDPICK_COLOR  31
#define AGEDEPLINE_COLOR      32
#define SEDRATE_COLOR         33
#define DATUMLOC_COLOR        34
#define TIMESERIES_COLOR      35

#define LOGO_BG     "gainsboro"
#define LOGO_FG     "red"

/* Colormap and Pixel array to hold the pixel values
   for foreground colors
*/
Colormap   cmap;
Pixel      fgPixel[NCOLOR];
Pixel      tempfgPixel[NCOLOR];
Pixel      bgPixel;
Pixel      tempbgPixel;

char prgfgcolor[50];
char prgbgcolor[50];
int  prgfg;             /* was foreground color read on command line args */
int  prgbg;             /* was background color read on command line args */


#define NCUSTOMECOLORBUTT     35

/* the color sets
*/
int colorset;

#define  EARTH_COLORSET      1
#define  CORPORATE_COLORSET  2
#define  SANTAFE_COLORSET    3
#define  ODP_COLORSET        4
#define  MARITIME_COLORSET   5
#define  CUSTOME_COLORSET    6


#define TOPLEFT   1
#define BOTLEFT   2
#define TOPRIGHT  3
#define BOTRIGHT  4

typedef struct _ErrRecord
{
  int     n_errs;
  int     err_line[TOOMANYREADERRORS];
} ErrRecord;
